@@ -8,13 +8,9 @@ class PDF::Annot::FileAttachment
     use PDF::COS::Tie;
     use PDF::COS::Name;
     use PDF::COS::ByteString;
-    use PDF::Filespec;
+    use PDF::Filespec :file-spec, :&to-file-spec;
 
-    my subset Filespec where PDF::COS::ByteString | PDF::Filespec; #| [PDF 32000-1:2008] 7.11.2 File Specification Strings
-    multi sub coerce(Hash $_, Filespec) {
-        PDF::COS.coerce($_,  PDF::Filespec);
-    }
-    has Filespec $.FS is entry(:required, :alias<file-spec>, :&coerce); #| (Required) The file associated with this annotation.
+    has file-spec $.FS is entry(:required, :alias<file-spec>, :coerce(&to-file-spec)); #| (Required) The file associated with this annotation.
     has PDF::COS::Name $.Name is entry(:alias<icon-name>);    #| (Optional) The name of an icon that is used in displaying the annotation. Conforming readers shall provide predefined icon appearances for at least the following standard names: GraphPushPin, PaperclipTag
 }
 
