@@ -18,22 +18,23 @@ role PDF::Destination
     use PDF::COS::Name;
 
     my subset PageRef where PDF::Page|UInt|Pair;
-    method is-page-ref { .[0] ~~ PDF::Page }
+    method is-page-ref { self.[0] ~~ PDF::Page }
     has PageRef $.page is index(0);
     has PDF::COS::Name $.fit is index(1);
     # See [PDF 1.7 TABLE 8.2 Destination syntax]
     multi sub is-destination(PageRef $page, 'XYZ', NumNull $left?,
-                             NumNull $top?, NumNull $zoom?)   { True }
-    multi sub is-destination(PageRef $page, 'Fit')                    { True }
-    multi sub is-destination(PageRef $page, 'FitH', NumNull $top?)    { True }
-    multi sub is-destination(PageRef $page, 'FitV', NumNull $left?)   { True }
+                             NumNull $top?, NumNull $zoom?)          { True }
+    multi sub is-destination(PageRef $page,)                         { True }
+    multi sub is-destination(PageRef $page, 'Fit')                   { True }
+    multi sub is-destination(PageRef $page, 'FitH', NumNull $top?)   { True }
+    multi sub is-destination(PageRef $page, 'FitV', NumNull $left?)  { True }
     multi sub is-destination(PageRef $page, 'FitR', Numeric $left,
                              Numeric $bottom, Numeric $right,
-                             Numeric $top )                   { True }
-    multi sub is-destination(PageRef $page, 'FitB')                   { True }
-    multi sub is-destination(PageRef $page, 'FitBH', NumNull $top?)   { True }
-    multi sub is-destination(PageRef $page, 'FitBV', NumNull $left?)  { True }
-    multi sub is-destination(|c) is default                   { False }
+                             Numeric $top )                          { True }
+    multi sub is-destination(PageRef $page, 'FitB')                  { True }
+    multi sub is-destination(PageRef $page, 'FitBH', NumNull $top?)  { True }
+    multi sub is-destination(PageRef $page, 'FitBV', NumNull $left?) { True }
+    multi sub is-destination(|c) is default                          { False }
 
     my subset DestinationArray of List is export(:DestinationArray) where is-destination(|$_);
 
@@ -60,6 +61,11 @@ role PDF::Destination
                            Numeric :$right!,  Numeric :$top!, )  { self!dest: [$page, fit(FitRect),   $left,
                                                                                                       $bottom, $right, $top] }
 
+    multi method construct(PageRef :$page!, )                    { self!dest: [$page, fit(FitWindow), ] }
+    multi method construct(DestinationArray $dest) { self.construct(|$dest) }
+    multi method construct(*@args) is default {
+        fail "unable to construct destination: {@args.perl}";
+    }
 
     # Coercions for explicit and named destinations
     # a named destination may be either a byte-string or name object
